Coverage for wagtailsharing/migrations/0001_initial.py: 100%

# Coverage for wagtailsharing/migrations/0001_initial.py : 100%

## 6 statements 6 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 | # -*- coding: utf-8 -*- from __future__ import unicode_literals import django.db.models.deletion from django.db import migrations, models class Migration(migrations.Migration): dependencies = [ ('wagtailcore', '0030_index_on_pagerevision_created_at'), ] operations = [ migrations.CreateModel( name='SharingSite', fields=[ ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)), ('hostname', models.CharField(max_length=255, db_index=True)), ('port', models.IntegerField(default=80)), ('site', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='sharing_site', to='wagtailcore.Site')), ], ), migrations.AlterUniqueTogether( name='sharingsite', unique_together=set([('hostname', 'port')]), ), ]